@@ -92,7 +92,7 @@ class Onglets(QTabWidget):
         # Creation de fonctions associees aux entrees du menu "Creer"
         self.creer = {}
         DG = dialogues_geometrie.__dict__
-        dialogues = [(nom[8:], DG[nom]) for nom in DG.keys() if nom.startswith("Dialogue")]
+        dialogues = [(nom[8:], DG[nom]) for nom in DG if nom.startswith("Dialogue")]
         for dialogue in dialogues:
             def f(event = None, self = self, dialogue = dialogue[1]):
                 self.creer_objet(dialogue)
