@@ -36,7 +36,6 @@ from ..pylib import property2, uu, str2, print_error, \
                     is_in, WeakList, CustomWeakKeyDictionary, warning
 from ..mathlib.parsers import mathtext_parser
 from .routines import nice_display
-from .constantes import NOM, RIEN#, FORMULE, TEXTE,
 ##from .formules import Formule
 from .contexte import contexte
 from .. import param
@@ -81,7 +80,15 @@ RE_NOM_DE_POINT="[A-Z]((_[{][0-9]+[}])|(_[0-9]+)|([']+))?"
 
 
 def issympy(*expressions):
-    return all(isinstance(e, Basic) for e in expressions)
+    from .variables import Variable
+    if len(expressions) > 1:
+        return all(issympy(expr) for expr in expressions)
+    elif not expressions:
+        return None
+    expr = expressions[0]
+    if isinstance(expr, Variable):
+        return isinstance(expr.contenu, Basic)
+    return isinstance(expr, Basic)
 
 
 
@@ -267,11 +274,6 @@ class Rendu(object):
         artiste._cree_par = self.parent
         return artiste
 
-    def _pixel(self, point = None):
-        if point is None:
-            point = self.parent
-        return self.canvas.coo2pix(*point.coordonnees_approchees)
-
 
 
 class Cache(object):
@@ -323,13 +325,6 @@ class Cache(object):
         self.__exact.clear()
 
 
-def pi_():
-    return PI if contexte['exact'] else math.pi
-
-def I_():
-    return I if contexte['exact'] else 1j
-
-
 
 class Ref(object):
     u"""Conteneur pour un argument d'un objet.
@@ -865,7 +860,7 @@ class Objet(object):
             >>> D1.label()
             ''
 
-            >>> D1.label(mode=NOM)
+            >>> D1.label(mode='nom')
             >>> print(D1.label())
             $\\mathscr{D}_{1}$
 
@@ -874,10 +869,10 @@ class Objet(object):
             Je suis une droite.
 
         Si le texte contient des formules entre accolades, elles
-        peuvent également être interprétées, si le mode FORMULE
+        peuvent également être interprétées, si le mode 'formule'
         est activé::
 
-            >>> D1.label("A a pour abscisse {A.x}.", mode=FORMULE)
+            >>> D1.label("A a pour abscisse {A.x}.", mode='formule')
             >>> D1.label()
             u'A a pour abscisse -2,7.'
 
@@ -990,9 +985,9 @@ class Objet(object):
             self.feuille.objets._dereferencer(self)
             self.feuille.objets[nom] = self
         if afficher_nom:
-            self.label(mode=NOM)
+            self.label(mode='nom')
         elif afficher_nom is False:
-            self.label(mode=RIEN)
+            self.label(mode='rien')
         self.style(**kw)
         self.figure_perimee()
 
@@ -1295,7 +1290,7 @@ class Objet(object):
     def _pixel(self, point = None):
         if point is None:
             point = self
-        return self.canvas.coo2pix(*point.coordonnees_approchees)
+        return self.feuille.coo2pix(*point.coordonnees_approchees)
 
 
     def message(self, message):
@@ -1754,10 +1749,6 @@ class Objet_avec_coordonnees(Objet):
     def _get_coordonnees(self):
         raise NotImplementedError
 
-    def _set_coordonnees(self):
-        raise NotImplementedError
-
-
     def __call__(self, *args):
         if args and not self.style("fixe"):
             if len(args) == 1:
