@@ -255,6 +255,7 @@ class Options(QWidget):
         self.cb_copie_automatique = cb = QCheckBox(self)
         cb.setChecked(prm("copie_automatique"))
         cb.stateChanged.connect(self.EvtCopieAutomatique)
+        cb.setToolTip(u"Copier automatiquement le résultat du calcul dans le presse-papier.")
         ligne.addWidget(cb)
         ligne.addWidget(QLabel(u"Copie du résultat dans le presse-papier."))
         ligne.addStretch()
@@ -264,6 +265,7 @@ class Options(QWidget):
         box_layout.addLayout(ligne)
         self.cb_copie_automatique_LaTeX = cb = QCheckBox(self)
         cb.setChecked(prm("copie_automatique_LaTeX"))
+        cb.setToolTip(u"Copier le résultat du calcul au format LaTeX dans le presse-papier.")
         ligne.addWidget(cb)
         cb.stateChanged.connect(self.EvtCopieAutomatiqueLatex)
         self.st_copie_automatique_LaTeX = st = QLabel(u"Copie au format LaTeX (si possible).")
@@ -350,7 +352,10 @@ class Avance(QWidget):
 
     def EvtAppliquerResultat(self, event=None):
         val = self.traitement.text().strip()
-        if val == '_':
+        if not val:
+            self.traitement.setText('_')
+            val = None
+        elif val == '_':
             val = None
         self.parent.param("appliquer_au_resultat", val)
 
