@@ -38,7 +38,7 @@ from ...GUI.menu import MenuBar
 from ...GUI.panel import Panel_API_graphique
 from ...GUI.proprietes_objets import Proprietes
 from ...GUI.qtlib import BusyCursor
-from ...geolib import Segment, Texte, Point, Champ, TEXTE
+from ...geolib import Segment, Texte, Point, Champ
 from ...geolib.routines import nice_str
 from ...pylib import OrderedDict, print_error
 from ...mathlib.parsers import convertir_en_latex, NBR, NBR_SIGNE
