@@ -5,6 +5,6 @@ NOMPROG = u"Géophar"
 NOMPROG2 = 'Geophar' # sans accent
 
 # Numéro de version (et date de sa sortie)
-version = '16.01'
-date_version = (2016, 1, 5)
-git = 'v15.10.2-4-g49ef9a4'
\ No newline at end of file
+version = '16.08.4'
+date_version = (2016, 11, 6)
+git = 'v16.08.3-2-gd654f7a'
\ No newline at end of file
